@@ -34,7 +34,11 @@ class WialonResource(WialonBase):
                 "skipCreatorCheck": int(skip_creator_check),
             }
         )
-        return int(response.get("item", {}).get("id")) if response.get("item") else None
+        return (
+            int(response.get("item", {}).get("id"))
+            if response and response.get("item")
+            else None
+        )
 
     def delete(self) -> None:
         """
@@ -58,12 +62,14 @@ class WialonResource(WialonBase):
         :type: :py:obj:`bool`
 
         """
-        if not self.is_account:
-            return False  # Resources cannot have dealer rights
-        return bool(
-            self.session.wialon_api.get_account_data(
-                **{"itemId": self.id, "type": 1}
-            ).get("dealerRights")
+        return (
+            bool(
+                self.session.wialon_api.get_account_data(
+                    **{"itemId": self.id, "type": 1}
+                ).get("dealerRights")
+            )
+            if self.is_account
+            else False
         )
 
     @property
@@ -302,10 +308,6 @@ class WialonResource(WialonBase):
         :type phone: :py:obj:`str`
         :param mobile_auth_code: Authentication code for Wialon mobile app.
         :type mobile_auth_code: :py:obj:`str`
-        :param image_checksum: Checksum for driver image.
-        :type image_checksum: :py:obj:`str`
-        :param image_ratio: Driver image aspect ratio.
-        :type image_ratio: :py:obj:`float` | :py:obj:`None`
         :param custom_fields: Additional custom fields to add to the driver.
         :type custom_fields: :py:obj:`dict` | :py:obj:`None`
         :raises WialonError: If something goes wrong calling the Wialon API.
